@@ -83,21 +83,6 @@ class Coordinator:
         out = '%s %s %s\n' % (s * sep_len, txt, s * (sep_len + sep_extra))
         sys.stdout.write(out)
 
-    def _populate_test_q(self):
-        """
-        Populate te test queue, separating grouped tests into lists as a single item in the queue
-        """
-        for test in self._tests:
-            # Function objects in pytest are not pickle-able, so have to send string nodeid and
-            # do lookup on worker side
-            if isinstance(test, list):
-                self._test_q.put([t.nodeid for t in test])
-            else:
-                self._test_q.put(test.nodeid)
-        for _ in self._processes:
-            self._test_q.put(None)  # signals end;  close() doesn't actually seem to work like it should :-/
-        self._test_q.close()
-
     def _output_summary(self):
         """
         Output the summary of test execution
@@ -160,17 +145,37 @@ class Coordinator:
 
         :param session: Pytest test session, to get session or config information
         """
-        self._populate_test_q()
-
         reader_mapping = {q._reader: q for q in self._result_qs}
+        def read_results(timeout=0):
+            available_qs = [q._reader for q in self._result_qs if q is not None]
+            (inputs, _, _) = select.select(available_qs, [], [], timeout)
+            while inputs:
+                for input in inputs:
+                    items = reader_mapping[input].get()
+                    for kind, data in items:
+                        self._process_worker_message(session, kind, data)
+                available_qs = [q._reader for q in self._result_qs if q is not None]
+                (inputs, _, _) = select.select(available_qs, [], [], 0)
+
+        #while any(self._result_qs):
+        for test in self._tests:
+            if all([q is None for q in self._result_qs ]):
+                raise Exception("Tests remain but no workers left to process them!")
+            read_results()
+            # Function objects in pytest are not pickle-able, so have to send string nodeid and
+            # do lookup on worker side
+            item = [t.nodeid for t in test] if isinstance(test, list) else test.nodeid
+            try:
+                self._test_q.put(item, timeout=1)
+            except Queue.Full:
+                pass
+
+        for _ in self._processes:
+            self._test_q.put(None)  # signals end
 
         while any(self._result_qs):
-            (inputs, _, _) = select.select([q._reader for q in self._result_qs if q is not None], [], [])
-            for input in inputs:
-                items = reader_mapping[input].get()
-                for kind, data in items:
-                    self._process_worker_message(session, kind, data)
-
+            read_results(timeout=1)
+        self._test_q.close()
         sys.stdout.write("\r\n")
         self._output_summary()
 
