@@ -7,7 +7,7 @@ import pytest
 
 from multiprocessing import cpu_count
 from pytest_mproc.coordinator import Coordinator
-from pytest_mproc_utils import _GlobalFixtures, is_degraded
+from pytest_mproc.utils import _GlobalFixtures, is_degraded
 
 
 def parse_numprocesses(s):
@@ -113,14 +113,18 @@ def pytest_runtestloop(session):
                             break
             except Exception:
                 print(f">>>> ERROR in global initializer {func.name}. Aborting!")
-                sys,exit(1)
+                sys.exit(1)
     if getattr(session.config.option, "numcores", None) is None or is_degraded() or getattr(session.config.option, "mproc_disabled"):
         return  # return of None indicates other hook impls will be executed to do the task at hand
     if not session.config.getvalue("collectonly") and worker is None:
         # main coordinator loop:
         with session.config.coordinator as coordinator:
             coordinator.set_items(session.items)
-            coordinator.run(session)
+            try:
+                coordinator.run(session)
+            except Exception as e:
+                print(">>> ERROR in run loop;  unexpected Exception\n %s" % str(e))
+                raise
     else:
         worker.test_loop(session)
     return True
