@@ -18,7 +18,7 @@ else:
 try:
     my_cov = None  # overriden later, after fork
     try:
-        original_cleanup = pytest_cov.embed.cleanup
+        original_cleanup = pytest_cov.embed.cleanupgit
     except:
         original_cleanup = None
 
