@@ -9,7 +9,7 @@ import pytest
 
 from testcode.dummy_src.something import to_be_run_under_test
 from testcode.testsomething import Something
-from pytest_mproc_utils import global_finalizer, global_initializer
+from pytest_mproc.utils import global_finalizer, global_initializer
 
 @pytest.fixture()
 def some_fixture():
